Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(610)

Unified Diff: third_party/WebKit/Source/core/layout/compositing/PaintLayerCompositor.cpp

Issue 2465983002: Rename "paint invalidation rect" etc. to "visual rect". (Closed)
Patch Set: - Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/layout/compositing/PaintLayerCompositor.cpp
diff --git a/third_party/WebKit/Source/core/layout/compositing/PaintLayerCompositor.cpp b/third_party/WebKit/Source/core/layout/compositing/PaintLayerCompositor.cpp
index ac8cf0379045d6489572d69262cc34cc9f67eb45..06a015ef2c4a8f2bacf9372b1d4ef78b07dbd2e5 100644
--- a/third_party/WebKit/Source/core/layout/compositing/PaintLayerCompositor.cpp
+++ b/third_party/WebKit/Source/core/layout/compositing/PaintLayerCompositor.cpp
@@ -357,21 +357,19 @@ void PaintLayerCompositor::updateWithoutAcceleratedCompositing(
#endif
}
-static void
-forceRecomputePaintInvalidationRectsIncludingNonCompositingDescendants(
+static void forceRecomputeVisualRectsIncludingNonCompositingDescendants(
LayoutObject* layoutObject) {
- // We clear the previous paint invalidation rect as it's wrong (paint
- // invalidation container changed, ...). Forcing a full invalidation will make
- // us recompute it. Also we are not changing the previous position from our
- // paint invalidation container, which is fine as we want a full paint
- // invalidation anyway.
- layoutObject->clearPreviousPaintInvalidationRects();
+ // We clear the previous visual rect as it's wrong (paint invalidation
+ // container changed, ...). Forcing a full invalidation will make us recompute
+ // it. Also we are not changing the previous position from our paint
+ // invalidation container, which is fine as we want a full paint invalidation
+ // anyway.
+ layoutObject->clearPreviousVisualRects();
for (LayoutObject* child = layoutObject->slowFirstChild(); child;
child = child->nextSibling()) {
if (!child->isPaintInvalidationContainer())
- forceRecomputePaintInvalidationRectsIncludingNonCompositingDescendants(
- child);
+ forceRecomputeVisualRectsIncludingNonCompositingDescendants(child);
}
}
@@ -481,7 +479,7 @@ void PaintLayerCompositor::updateIfNeeded() {
}
for (unsigned i = 0; i < layersNeedingPaintInvalidation.size(); i++)
- forceRecomputePaintInvalidationRectsIncludingNonCompositingDescendants(
+ forceRecomputeVisualRectsIncludingNonCompositingDescendants(
layersNeedingPaintInvalidation[i]->layoutObject());
// Inform the inspector that the layer tree has changed.

Powered by Google App Engine
This is Rietveld 408576698